@@ -1,5 +1,5 @@
-from .api import E621, E926
+from .e621 import e621
 
 __author__ = "PatriotRossii"
-__version__ = "0.0.7"
+__version__ = "0.1.0"
 __email__ = "patriotrosii2019@mail.ru"
